<?php

namespace Lavalite\Purposes\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Lavalite\Purposes\Http\Requests\ProductsPurposeRequest;
use Lavalite\Purposes\Models\ProductsPurpose;

/**
 * Admin web controller class.
 */
class ProductsPurposeWorkflowController extends BaseController
{

    /**
     * Workflow controller function for products_purpose.
     *
     * @param Model   $products_purpose
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ProductsPurposeRequest $request, ProductsPurpose $products_purpose, $step)
    {

        try {

            $products_purpose->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('purposes::products_purpose.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/products_purpose/products_purpose/' . $products_purpose->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/products_purpose/products_purpose/' . $products_purpose->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for products_purpose.
     *
     * @param Model   $products_purpose
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(ProductsPurpose $products_purpose, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $products_purpose->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('purposes::products_purpose.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('purposes::admin.products_purpose.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('purposes::admin.products_purpose.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('purposes::admin.products_purpose.message', $data)->render();

        }

    }
}
