<?php

namespace Lavalite\Purpose\Policies;

use Litepie\User\Contracts\UserPolicy;
use Lavalite\Purpose\Models\ProductsPurpose;

class ProductsPurposePolicy
{

    /**
     * Determine if the given user can view the products_purpose.
     *
     * @param UserPolicy $user
     * @param ProductsPurpose $products_purpose
     *
     * @return bool
     */
    public function view(UserPolicy $user, ProductsPurpose $products_purpose)
    {
        if ($user->canDo('purpose.products_purpose.view') && $user->isAdmin()) {
            return true;
        }

        return $products_purpose->user_id == user_id() && $products_purpose->user_type == user_type();
    }

    /**
     * Determine if the given user can create a products_purpose.
     *
     * @param UserPolicy $user
     * @param ProductsPurpose $products_purpose
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('purpose.products_purpose.create');
    }

    /**
     * Determine if the given user can update the given products_purpose.
     *
     * @param UserPolicy $user
     * @param ProductsPurpose $products_purpose
     *
     * @return bool
     */
    public function update(UserPolicy $user, ProductsPurpose $products_purpose)
    {
        if ($user->canDo('purpose.products_purpose.edit') && $user->isAdmin()) {
            return true;
        }

        return $products_purpose->user_id == user_id() && $products_purpose->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given products_purpose.
     *
     * @param UserPolicy $user
     * @param ProductsPurpose $products_purpose
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ProductsPurpose $products_purpose)
    {
        return $products_purpose->user_id == user_id() && $products_purpose->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given products_purpose.
     *
     * @param UserPolicy $user
     * @param ProductsPurpose $products_purpose
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ProductsPurpose $products_purpose)
    {
        if ($user->canDo('purpose.products_purpose.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given products_purpose.
     *
     * @param UserPolicy $user
     * @param ProductsPurpose $products_purpose
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ProductsPurpose $products_purpose)
    {
        if ($user->canDo('purpose.products_purpose.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
