<?php

namespace Lavalite\Purposes\Providers;

use Illuminate\Support\ServiceProvider;

class PurposesServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'purposes');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'purposes');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('lavalite.purposes', function ($app) {
            return $this->app->make('Lavalite\Purposes\Purposes');
        });

                // Bind ProductsPurpose to repository
        $this->app->bind(
            'Lavalite\Purposes\Interfaces\ProductsPurposeRepositoryInterface',
            \Lavalite\Purposes\Repositories\Eloquent\ProductsPurposeRepository::class
        );

        $this->app->register(\Lavalite\Purposes\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Lavalite\Purposes\Providers\RouteServiceProvider::class);
                $this->app->register(\Lavalite\Purposes\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['lavalite.purposes'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('lavalite/purposes.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/purposes')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/purposes')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
