<?php

namespace Lavalite\Purposes\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Lavalite\Purposes\Models\ProductsPurpose;

class ProductsPurposeAction
{
    /**
     * Perform the complete action.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return ProductsPurpose
     */
    public function complete(ProductsPurpose $products_purpose)
    {
        try {
            $products_purpose->status = 'complete';
            return $products_purpose->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return ProductsPurpose
     */public function verify(ProductsPurpose $products_purpose)
    {
        try {
            $products_purpose->status = 'verify';
            return $products_purpose->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return ProductsPurpose
     */public function approve(ProductsPurpose $products_purpose)
    {
        try {
            $products_purpose->status = 'approve';
            return $products_purpose->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return ProductsPurpose
     */public function publish(ProductsPurpose $products_purpose)
    {
        try {
            $products_purpose->status = 'publish';
            return $products_purpose->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return ProductsPurpose
     */
    public function archive(ProductsPurpose $products_purpose)
    {
        try {
            $products_purpose->status = 'archive';
            return $products_purpose->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return ProductsPurpose
     */
    public function unpublish(ProductsPurpose $products_purpose)
    {
        try {
            $products_purpose->status = 'unpublish';
            return $products_purpose->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
