<?php

namespace Lavalite\Purposes\Workflow;

use Lavalite\Purposes\Models\ProductsPurpose;
use Validator;

class ProductsPurposeValidator
{

    /**
     * Determine if the given products_purpose is valid for complete status.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return bool / Validator
     */
    public function complete(ProductsPurpose $products_purpose)
    {
        return Validator::make($products_purpose->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given products_purpose is valid for verify status.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return bool / Validator
     */
    public function verify(ProductsPurpose $products_purpose)
    {
        return Validator::make($products_purpose->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given products_purpose is valid for approve status.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return bool / Validator
     */
    public function approve(ProductsPurpose $products_purpose)
    {
        return Validator::make($products_purpose->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given products_purpose is valid for publish status.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return bool / Validator
     */
    public function publish(ProductsPurpose $products_purpose)
    {
        return Validator::make($products_purpose->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given products_purpose is valid for archive status.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return bool / Validator
     */
    public function archive(ProductsPurpose $products_purpose)
    {
        return Validator::make($products_purpose->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given products_purpose is valid for unpublish status.
     *
     * @param ProductsPurpose $products_purpose
     *
     * @return bool / Validator
     */
    public function unpublish(ProductsPurpose $products_purpose)
    {
        return Validator::make($products_purpose->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
